@@ -26,6 +26,35 @@ class EmrClient(AbstractClient):
     _service = 'emr'
 
 
+    def AddUsersForUserManager(self, request):
+        """新增用户列表（用户管理）
+
+        :param request: Request instance for AddUsersForUserManager.
+        :type request: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddUsersForUserManager", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddUsersForUserManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstance(self, request):
         """创建EMR集群实例
 
@@ -171,6 +200,35 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInstancesList(self, request):
+        """EMR集群实例列表查询
+
+        :param request: Request instance for DescribeInstancesList.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesListRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeInstancesListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstancesList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInstancesListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeJobFlow(self, request):
         """查询流程任务
 
@@ -200,6 +258,64 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeResourceSchedule(self, request):
+        """获取yarn资源调度页面的数据
+
+        :param request: Request instance for DescribeResourceSchedule.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeResourceScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResourceSchedule", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeResourceScheduleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeUsersForUserManager(self, request):
+        """批量导出用户
+
+        :param request: Request instance for DescribeUsersForUserManager.
+        :type request: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeUsersForUserManager", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUsersForUserManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceRenewEmr(self, request):
         """集群续费询价。
 
@@ -345,6 +461,93 @@ class EmrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyResourcePools(self, request):
+        """刷新动态资源池
+
+        :param request: Request instance for ModifyResourcePools.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourcePoolsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourcePools", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourcePoolsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyResourceScheduleConfig(self, request):
+        """修改yarn资源调度的资源配置
+
+        :param request: Request instance for ModifyResourceScheduleConfig.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceScheduleConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourceScheduleConfig", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourceScheduleConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyResourceScheduler(self, request):
+        """修改了yarn的资源调度器，点击部署生效
+
+        :param request: Request instance for ModifyResourceScheduler.
+        :type request: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerRequest`
+        :rtype: :class:`tencentcloud.emr.v20190103.models.ModifyResourceSchedulerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyResourceScheduler", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyResourceSchedulerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RunJobFlow(self, request):
         """创建流程作业
 
